@@ -23,20 +23,25 @@
 
 int main (int argc, char *argv[])
 {
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
     Gnome::Conf::init();
     Gtk::Main kit(argc, argv);
 
     Window_Test windowTest;
    
     kit.run(windowTest);
+
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   }
   catch(const Glib::Error& ex)
   {
     //GConf::Client can throw exceptions.
     std::cout << ex.what() << std::endl;
   }
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 
   return 0;
 }
